package App::samelines ;  
our $VERSION = '0.033' ; 
our $DATE = '2024-03-16T00:19+09:00' ; 

=encoding utf8

=head1 NAME

App::samelines -- The command shows the circumstances about how "same lines" appear in the input. 

- The circumstances can be output according to the layers which is performed by specifying the column number.

=head1 SYNOPSIS

This module provides a Unix-like command `F<samelines>'. 

=head1 DESCRIPTION

=head1 SEE ALSO

samelines --help
man samelines
perldoc samelines

=head1 AUTHOR

下野寿之 早稲田大学 スマート社会技術融合研究機構

=cut

1 ;
